Interface: TickOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TickOptions

## # Properties

### # backdropColor

• backdropColor: `Scriptable`<`Color`, `ScriptableScaleContext`>

Color of label backdrops.

`default` 'rgba(255, 255, 255, 0.75)'

#### # Defined in

index.esm.d.ts:2923
(opens new window)

### # backdropPadding

• backdropPadding: `number` | `ChartArea`

Padding of tick backdrop.

`default` 2

#### # Defined in

index.esm.d.ts:2928
(opens new window)

### # color

• color: `ScriptableAndArray`<`Color`, `ScriptableScaleContext`>

Color of tick

`see` Defaults.color

#### # Defined in

index.esm.d.ts:2943
(opens new window)

### # display

• display: `boolean`

If true, show tick labels.

`default` true

#### # Defined in

index.esm.d.ts:2938
(opens new window)

### # font

• font: `ScriptableAndScriptableOptions`<`Partial`<`FontSpec`>, `ScriptableScaleContext`>

see Fonts

#### # Defined in

index.esm.d.ts:2947
(opens new window)

### # major

• major: `Object`

#### # Type declaration

Name | Type | Description
--- | --- | ---
`enabled` | `boolean` | If true, major ticks are generated. A major tick will affect autoskipping and major will be defined on ticks in the scriptable options context. `default` false

#### # Defined in

index.esm.d.ts:2973
(opens new window)

### # padding

• padding: `number`

Sets the offset of the tick labels from the axis

#### # Defined in

index.esm.d.ts:2951
(opens new window)

### # showLabelBackdrop

• showLabelBackdrop: `Scriptable`<`boolean`, `ScriptableScaleContext`>

If true, draw a background behind the tick labels.

`default` false

#### # Defined in

index.esm.d.ts:2956
(opens new window)

### # textStrokeColor

• textStrokeColor: `Scriptable`<`Color`, `ScriptableScaleContext`>

The color of the stroke around the text.

`default` undefined

#### # Defined in

index.esm.d.ts:2961
(opens new window)

### # textStrokeWidth

• textStrokeWidth: `Scriptable`<`number`, `ScriptableScaleContext`>

Stroke width around the text.

`default` 0

#### # Defined in

index.esm.d.ts:2966
(opens new window)

### # z

• z: `number`

z-index of tick layer. Useful when ticks are drawn on chart area. Values <= 0 are drawn under datasets, > 0 on top.

`default` 0

#### # Defined in

index.esm.d.ts:2971
(opens new window)

## # Methods

### # callback

▸ callback(`tickValue`, `index`, `ticks`): `string` | `number` | `string`[] | `number`[]

Returns the string representation of the tick value as it should be displayed on the chart. See callback.

#### # Parameters

Name | Type
--- | ---
`tickValue` | `string` | `number`
`index` | `number`
`ticks` | `Tick`[]

#### # Returns

`string` | `number` | `string`[] | `number`[]

#### # Defined in

index.esm.d.ts:2933
(opens new window)